@@ -203,8 +203,8 @@ class GameServerDeploymentsServiceAsyncClient:
                 The request object. Request message for
                 GameServerDeploymentsService.ListGameServerDeployments.
             parent (:class:`str`):
-                Required. The parent resource name. Uses the form:
-                ``projects/{project}/locations/{location}``.
+                Required. The parent resource name, in the following
+                form: ``projects/{project}/locations/{location}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -293,8 +293,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 GameServerDeploymentsService.GetGameServerDeployment.
             name (:class:`str`):
                 Required. The name of the game server delpoyment to
-                retrieve. Uses the form:
-
+                retrieve, in the following form:
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}``.
 
                 This corresponds to the ``name`` field
@@ -374,8 +373,8 @@ class GameServerDeploymentsServiceAsyncClient:
                 The request object. Request message for
                 GameServerDeploymentsService.CreateGameServerDeployment.
             parent (:class:`str`):
-                Required. The parent resource name. Uses the form:
-                ``projects/{project}/locations/{location}``.
+                Required. The parent resource name, in the following
+                form: ``projects/{project}/locations/{location}``.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -466,8 +465,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 GameServerDeploymentsService.DeleteGameServerDeployment.
             name (:class:`str`):
                 Required. The name of the game server delpoyment to
-                delete. Uses the form:
-
+                delete, in the following form:
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}``.
 
                 This corresponds to the ``name`` field
@@ -571,9 +569,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 Required. Mask of fields to update. At least one path
                 must be supplied in this field. For the ``FieldMask``
                 definition, see
-
-                https: //developers.google.com/protocol-buffers //
-                /docs/reference/google.protobuf#fieldmask
+                https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -659,8 +655,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 GameServerDeploymentsService.GetGameServerDeploymentRollout.
             name (:class:`str`):
                 Required. The name of the game server delpoyment to
-                retrieve. Uses the form:
-
+                retrieve, in the following form:
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/rollout``.
 
                 This corresponds to the ``name`` field
@@ -759,9 +754,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 Required. Mask of fields to update. At least one path
                 must be supplied in this field. For the ``FieldMask``
                 definition, see
-
-                https: //developers.google.com/protocol-buffers //
-                /docs/reference/google.protobuf#fieldmask
+                https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -940,9 +933,9 @@ class GameServerDeploymentsServiceAsyncClient:
                 predicate=retries.if_exception_type(
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=120.0,
+                deadline=60.0,
             ),
-            default_timeout=120.0,
+            default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
