@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -386,7 +386,9 @@ class GameServerDeploymentsServiceClient(
 
     def list_game_server_deployments(
         self,
-        request: game_server_deployments.ListGameServerDeploymentsRequest = None,
+        request: Union[
+            game_server_deployments.ListGameServerDeploymentsRequest, dict
+        ] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -397,7 +399,7 @@ class GameServerDeploymentsServiceClient(
         location.
 
         Args:
-            request (google.cloud.gaming_v1.types.ListGameServerDeploymentsRequest):
+            request (Union[google.cloud.gaming_v1.types.ListGameServerDeploymentsRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.ListGameServerDeployments.
             parent (str):
@@ -471,7 +473,9 @@ class GameServerDeploymentsServiceClient(
 
     def get_game_server_deployment(
         self,
-        request: game_server_deployments.GetGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.GetGameServerDeploymentRequest, dict
+        ] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -481,7 +485,7 @@ class GameServerDeploymentsServiceClient(
         r"""Gets details of a single game server deployment.
 
         Args:
-            request (google.cloud.gaming_v1.types.GetGameServerDeploymentRequest):
+            request (Union[google.cloud.gaming_v1.types.GetGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.GetGameServerDeployment.
             name (str):
@@ -545,7 +549,9 @@ class GameServerDeploymentsServiceClient(
 
     def create_game_server_deployment(
         self,
-        request: game_server_deployments.CreateGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.CreateGameServerDeploymentRequest, dict
+        ] = None,
         *,
         parent: str = None,
         game_server_deployment: game_server_deployments.GameServerDeployment = None,
@@ -557,7 +563,7 @@ class GameServerDeploymentsServiceClient(
         project and location.
 
         Args:
-            request (google.cloud.gaming_v1.types.CreateGameServerDeploymentRequest):
+            request (Union[google.cloud.gaming_v1.types.CreateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.CreateGameServerDeployment.
             parent (str):
@@ -642,7 +648,9 @@ class GameServerDeploymentsServiceClient(
 
     def delete_game_server_deployment(
         self,
-        request: game_server_deployments.DeleteGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.DeleteGameServerDeploymentRequest, dict
+        ] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -652,7 +660,7 @@ class GameServerDeploymentsServiceClient(
         r"""Deletes a single game server deployment.
 
         Args:
-            request (google.cloud.gaming_v1.types.DeleteGameServerDeploymentRequest):
+            request (Union[google.cloud.gaming_v1.types.DeleteGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.DeleteGameServerDeployment.
             name (str):
@@ -739,7 +747,9 @@ class GameServerDeploymentsServiceClient(
 
     def update_game_server_deployment(
         self,
-        request: game_server_deployments.UpdateGameServerDeploymentRequest = None,
+        request: Union[
+            game_server_deployments.UpdateGameServerDeploymentRequest, dict
+        ] = None,
         *,
         game_server_deployment: game_server_deployments.GameServerDeployment = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -750,7 +760,7 @@ class GameServerDeploymentsServiceClient(
         r"""Patches a game server deployment.
 
         Args:
-            request (google.cloud.gaming_v1.types.UpdateGameServerDeploymentRequest):
+            request (Union[google.cloud.gaming_v1.types.UpdateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.UpdateGameServerDeployment.
                 Only allows updates for labels.
@@ -840,7 +850,9 @@ class GameServerDeploymentsServiceClient(
 
     def get_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.GetGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.GetGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -850,7 +862,7 @@ class GameServerDeploymentsServiceClient(
         r"""Gets details a single game server deployment rollout.
 
         Args:
-            request (google.cloud.gaming_v1.types.GetGameServerDeploymentRolloutRequest):
+            request (Union[google.cloud.gaming_v1.types.GetGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.GetGameServerDeploymentRollout.
             name (str):
@@ -919,7 +931,9 @@ class GameServerDeploymentsServiceClient(
 
     def update_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.UpdateGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.UpdateGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
         rollout: game_server_deployments.GameServerDeploymentRollout = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -936,7 +950,7 @@ class GameServerDeploymentsServiceClient(
         an error.
 
         Args:
-            request (google.cloud.gaming_v1.types.UpdateGameServerDeploymentRolloutRequest):
+            request (Union[google.cloud.gaming_v1.types.UpdateGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.UpdateGameServerRolloutDeployment.
             rollout (google.cloud.gaming_v1.types.GameServerDeploymentRollout):
@@ -1028,7 +1042,9 @@ class GameServerDeploymentsServiceClient(
 
     def preview_game_server_deployment_rollout(
         self,
-        request: game_server_deployments.PreviewGameServerDeploymentRolloutRequest = None,
+        request: Union[
+            game_server_deployments.PreviewGameServerDeploymentRolloutRequest, dict
+        ] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1038,7 +1054,7 @@ class GameServerDeploymentsServiceClient(
         does not mutate the rollout resource.
 
         Args:
-            request (google.cloud.gaming_v1.types.PreviewGameServerDeploymentRolloutRequest):
+            request (Union[google.cloud.gaming_v1.types.PreviewGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
                 PreviewGameServerDeploymentRollout.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1089,7 +1105,9 @@ class GameServerDeploymentsServiceClient(
 
     def fetch_deployment_state(
         self,
-        request: game_server_deployments.FetchDeploymentStateRequest = None,
+        request: Union[
+            game_server_deployments.FetchDeploymentStateRequest, dict
+        ] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1101,7 +1119,7 @@ class GameServerDeploymentsServiceClient(
         older version of the game server deployment.
 
         Args:
-            request (google.cloud.gaming_v1.types.FetchDeploymentStateRequest):
+            request (Union[google.cloud.gaming_v1.types.FetchDeploymentStateRequest, dict]):
                 The request object. Request message for
                 GameServerDeploymentsService.FetchDeploymentState.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
